@@ -1,6 +1,10 @@
 // [[Rcpp::plugins(openmp)]]
 #include <Rcpp.h>
+#ifdef _OPENMP
 #include <omp.h>
+#else
+#define omp_get_thread_num() 0
+#endif
 using namespace Rcpp;
 
 //' @title LDA of a pair of SNPs
